/* ssl_idea.h */
/* Copyright (C) 1995 Eric Young (eay@mincom.oz.au).
 * All rights reserved.
 * Copyright remains Eric Young's, and as such any Copyright notices in
 * the code are not to be removed.
 * See the COPYRIGHT file in the SSLeay distribution for more details.
 */

typedef struct idea_state_st
	{
	IDEA_KEY_SCHEDULE idea_read_ks;
	IDEA_KEY_SCHEDULE idea_write_ks;
	unsigned char read_iv[8];
	unsigned char write_iv[8];
	} IDEA_CBC_STATE;

#ifdef PROTO
int ssl_enc_idea_cbc_init(SSL *s, int client);
void ssl_enc_idea_cbc(SSL *s);
#else
int ssl_enc_idea_cbc_init();
void ssl_enc_idea_cbc();
#endif
